summaryrefslogtreecommitdiffstats
path: root/src/datasets
diff options
context:
space:
mode:
authorKore Nordmann <github@kore-nordmann.de>2006-08-07 07:48:06 +0000
committerKore Nordmann <github@kore-nordmann.de>2006-08-07 07:48:06 +0000
commitb31a0055fe42a14356400ebe6d7a8e5bebb26240 (patch)
treee7bb23aeeb54e09055bfd73539a08f7460aedaa3 /src/datasets
parentf0c3843559d630bcd9458e8f5b15185445dd173b (diff)
downloadzetacomponents-graph-b31a0055fe42a14356400ebe6d7a8e5bebb26240.zip
zetacomponents-graph-b31a0055fe42a14356400ebe6d7a8e5bebb26240.tar.gz
- Renamed Dataset to DataSet
Diffstat (limited to 'src/datasets')
-rw-r--r--src/datasets/average.php4
-rw-r--r--src/datasets/base.php20
-rw-r--r--src/datasets/property/boolean.php4
-rw-r--r--src/datasets/property/color.php4
-rw-r--r--src/datasets/property/integer.php4
-rw-r--r--src/datasets/property/string.php4
6 files changed, 20 insertions, 20 deletions
diff --git a/src/datasets/average.php b/src/datasets/average.php
index b0af528..7d9a662 100644
--- a/src/datasets/average.php
+++ b/src/datasets/average.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the abstract ezcGraphDatasetAverage class
*
* @package Graph
* @version //autogentag//
@@ -12,7 +12,7 @@
*
* @package Graph
*/
-class ezcGraphDatasetAverage extends ezcDataset
+class ezcGraphDataSetAverage extends ezcDataSet
{
}
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the abstract ezcGraphDatasetAverage class
+ * File containing the abstract ezcGraphDataSetAverage class
*
* @package Graph
diff --git a/src/datasets/base.php b/src/datasets/base.php
index b3c76c1..849f996 100644
--- a/src/datasets/base.php
+++ b/src/datasets/base.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the abstract ezcGraphDataset class
*
* @package Graph
* @version //autogentag//
@@ -12,34 +12,34 @@
*
* @package Graph
*/
-class ezcGraphDataset implements ArrayAccess, Iterator
+class ezcGraphDataSet implements ArrayAccess, Iterator
{
/**
* labels for dataset and dataset elements
*
- * @var ezcGraphDatasetStringProperty
+ * @var ezcGraphDataSetStringProperty
*/
protected $label;
/**
* Colors for dataset elements
*
- * @var ezcGraphDatasetColorProperty
+ * @var ezcGraphDataSetColorProperty
*/
protected $color;
/**
* Symbols for dataset elements
*
- * @var ezcGraphDatasetIntProperty
+ * @var ezcGraphDataSetIntProperty
*/
protected $symbol;
/**
* Status if dataset element is hilighted
*
- * @var ezcGraphDatasetBooleanProperty
+ * @var ezcGraphDataSetBooleanProperty
* @access protected
*/
protected $highlight;
@@ -68,10 +68,10 @@ class ezcGraphDataset implements ArrayAccess, Iterator
public function __construct()
{
- $this->label = new ezcGraphDatasetStringProperty( $this );
- $this->color = new ezcGraphDatasetColorProperty( $this );
- $this->symbol = new ezcGraphDatasetIntProperty( $this );
- $this->highlight = new ezcGraphDatasetBooleanProperty( $this );
+ $this->label = new ezcGraphDataSetStringProperty( $this );
+ $this->color = new ezcGraphDataSetColorProperty( $this );
+ $this->symbol = new ezcGraphDataSetIntProperty( $this );
+ $this->highlight = new ezcGraphDataSetBooleanProperty( $this );
$this->highlight->default = false;
}
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the abstract ezcGraphDataset class
+ * File containing the abstract ezcGraphDataSet class
*
* @package Graph
diff --git a/src/datasets/property/boolean.php b/src/datasets/property/boolean.php
index 318910d..5fad495 100644
--- a/src/datasets/property/boolean.php
+++ b/src/datasets/property/boolean.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the abstract ezcGraphDatasetBooleanProperty class
*
* @package Graph
* @version //autogentag//
@@ -12,7 +12,7 @@
*
* @package Graph
*/
-class ezcGraphDatasetBooleanProperty extends ezcGraphDatasetProperty
+class ezcGraphDataSetBooleanProperty extends ezcGraphDataSetProperty
{
/**
* Converts value to an ezcGraphColor object
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the abstract ezcGraphDatasetBooleanProperty class
+ * File containing the abstract ezcGraphDataSetBooleanProperty class
*
* @package Graph
diff --git a/src/datasets/property/color.php b/src/datasets/property/color.php
index 4a9d8ba..c963e39 100644
--- a/src/datasets/property/color.php
+++ b/src/datasets/property/color.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the abstract ezcGraphDatasetColorProperty class
*
* @package Graph
* @version //autogentag//
@@ -12,7 +12,7 @@
*
* @package Graph
*/
-class ezcGraphDatasetColorProperty extends ezcGraphDatasetProperty
+class ezcGraphDataSetColorProperty extends ezcGraphDataSetProperty
{
/**
* Converts value to an ezcGraphColor object
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the abstract ezcGraphDatasetColorProperty class
+ * File containing the abstract ezcGraphDataSetColorProperty class
*
* @package Graph
diff --git a/src/datasets/property/integer.php b/src/datasets/property/integer.php
index 28bf7b5..7497c30 100644
--- a/src/datasets/property/integer.php
+++ b/src/datasets/property/integer.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the abstract ezcGraphDatasetIntProperty class
*
* @package Graph
* @version //autogentag//
@@ -12,7 +12,7 @@
*
* @package Graph
*/
-class ezcGraphDatasetIntProperty extends ezcGraphDatasetProperty
+class ezcGraphDataSetIntProperty extends ezcGraphDataSetProperty
{
/**
* Converts value to an ezcGraphColor object
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the abstract ezcGraphDatasetIntProperty class
+ * File containing the abstract ezcGraphDataSetIntProperty class
*
* @package Graph
diff --git a/src/datasets/property/string.php b/src/datasets/property/string.php
index 98eb272..b893755 100644
--- a/src/datasets/property/string.php
+++ b/src/datasets/property/string.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the abstract ezcGraphDatasetStringProperty class
*
* @package Graph
* @version //autogentag//
@@ -12,7 +12,7 @@
*
* @package Graph
*/
-class ezcGraphDatasetStringProperty extends ezcGraphDatasetProperty
+class ezcGraphDataSetStringProperty extends ezcGraphDataSetProperty
{
/**
* Converts value to an ezcGraphColor object
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the abstract ezcGraphDatasetStringProperty class
+ * File containing the abstract ezcGraphDataSetStringProperty class
*
* @package Graph
OpenPOWER on IntegriCloud